@@ -1,10 +1,10 @@
-/* $Id: main.c 914 2006-10-25 17:12:22Z oetiker $
+/* $Id: main.c 1212 2007-11-08 10:13:48Z oetiker $
  * Substantial penalty for early withdrawal.
  */
 
 #include <unistd.h>
 #include <ruby.h>
-#include <rrd.h>
+#include "../../src/rrd_tool.h"
 
 typedef struct string_arr_t {
     int len;
@@ -43,7 +43,7 @@ string_arr string_arr_new(VALUE rb_strings)
             a.strings[i + 1] = strdup(buf);
             break;
         default:
-            rb_raise(rb_eTypeError, "invalid argument");
+            rb_raise(rb_eTypeError, "invalid argument - %s, expected T_STRING or T_FIXNUM on index %d", rb_class2name(CLASS_OF(v)), i);
             break;
         }
     }
@@ -130,10 +130,10 @@ VALUE rb_rrd_fetch(VALUE self, VALUE args)
     free(raw_data);
    
     result = rb_ary_new2(4);
-    rb_ary_store(result, 0, INT2FIX(start));
-    rb_ary_store(result, 1, INT2FIX(end));
+    rb_ary_store(result, 0, INT2NUM(start));
+    rb_ary_store(result, 1, INT2NUM(end));
     rb_ary_store(result, 2, names);
-    rb_ary_store(result, 2, data);
+    rb_ary_store(result, 3, data);
     return result;
 }
 
@@ -166,11 +166,10 @@ VALUE rb_rrd_graph(VALUE self, VALUE args)
     return result;
 }
 
-/*
 VALUE rb_rrd_info(VALUE self, VALUE args)
 {
     string_arr a;
-    info_t *p;
+    info_t *p, *data;
     VALUE result;
 
     a = string_arr_new(args);
@@ -184,19 +183,19 @@ VALUE rb_rrd_info(VALUE self, VALUE args)
         VALUE key = rb_str_new2(data->key);
         switch (data->type) {
         case RD_I_VAL:
-            if (isnan(data->u_val)) {
+            if (isnan(data->value.u_val)) {
                 rb_hash_aset(result, key, Qnil);
             }
             else {
-                rb_hash_aset(result, key, rb_float_new(data->u_val));
+                rb_hash_aset(result, key, rb_float_new(data->value.u_val));
             }
             break;
         case RD_I_CNT:
-            rb_hash_aset(result, key, INT2FIX(data->u_cnt));
+            rb_hash_aset(result, key, INT2FIX(data->value.u_cnt));
             break;
         case RD_I_STR:
-            rb_hash_aset(result, key, rb_str_new2(data->u_str));
-            free(data->u_str);
+            rb_hash_aset(result, key, rb_str_new2(data->value.u_str));
+            free(data->value.u_str);
             break;
         }
         p = data;
@@ -205,7 +204,6 @@ VALUE rb_rrd_info(VALUE self, VALUE args)
     }
     return result;
 }
-*/
 
 VALUE rb_rrd_last(VALUE self, VALUE args)
 {
@@ -256,4 +254,5 @@ void Init_RRD()
     rb_define_module_function(mRRD, "restore", rb_rrd_restore, -2);
     rb_define_module_function(mRRD, "tune", rb_rrd_tune, -2);
     rb_define_module_function(mRRD, "update", rb_rrd_update, -2);
+    rb_define_module_function(mRRD, "info", rb_rrd_info, -2);
 }
