@@ -1,5 +1,5 @@
 /*****************************************************************************
- * RRDtool 1.2.27  Copyright by Tobi Oetiker, 1997-2008
+ * RRDtool 1.2.28  Copyright by Tobi Oetiker, 1997-2008
  *****************************************************************************
  * rrd_info  Get Information about the configuration of an RRD
  *****************************************************************************/
@@ -155,6 +155,9 @@ rrd_info_r(char *filename) {
 	info.u_cnt=rrd.rra_def[i].row_cnt;
 	cd=info_push(cd,sprintf_alloc("rra[%d].rows",i),  RD_I_CNT,   info);
 
+	info.u_cnt=rrd.rra_ptr[i].cur_row;
+	cd=info_push(cd,sprintf_alloc("rra[%d].cur_row",i),  RD_I_CNT,   info);
+
 	info.u_cnt=rrd.rra_def[i].pdp_cnt;
 	cd=info_push(cd,sprintf_alloc("rra[%d].pdp_per_row",i),  RD_I_CNT,   info);
 
