@@ -1,5 +1,5 @@
 /*****************************************************************************
- * RRDtool 1.2.27  Copyright by Tobi Oetiker, 1997-2008
+ * RRDtool 1.2.28  Copyright by Tobi Oetiker, 1997-2008
  * This file:     Copyright 2003 Peter Stamfest <peter@stamfest.at> 
  *                             & Tobias Oetiker
  * Distributed under the GPL
@@ -7,7 +7,7 @@
  * rrd_not_thread_safe.c   Contains routines used when thread safety is not
  *                         an issue
  *****************************************************************************
- * $Id: rrd_not_thread_safe.c 1286 2008-02-17 10:08:10Z oetiker $
+ * $Id: rrd_not_thread_safe.c 1450 2008-07-23 13:45:41Z oetiker $
  *************************************************************************** */
 #include "rrd.h"
 #include "rrd_tool.h"
@@ -23,8 +23,8 @@ static int  rrd_context_init = 0;
 static struct rrd_context global_ctx = {
     MAXLEN,
     ERRBUFLEN,
+    rrd_liberror,
     rrd_error, 
-    rrd_liberror
 };
 /* #include <stdarg.h> */
 
